@@ -23,14 +23,14 @@ from base_device_module import deviceModule
 
 # NOTE: use the device_ prefix when naming the module
 
-def getModule(m,d):
-  return(device_example(m,d))
+def getModule(m,d,i):
+  return(device_example(m,d,i))
 
 class device_example(deviceModule):
   """A sample modRana device-specific module"""
   
-  def __init__(self, m, d):
-    deviceModule.__init__(self, m, d)
+  def __init__(self, m, d, i):
+    deviceModule.__init__(self, m, d, i)
     
 
 if(__name__ == "__main__"):
