@@ -84,12 +84,6 @@ class device_n900(deviceModule):
     is-active == False signalizes that the window is either minimzed on the
     dashboard or the screen is blanked
     """
-  def update(self):
-    """initialize the automatic rotation"""
-    if not self.done:
-      if self.topWindow: #TODO: do this more efficiently
-        self.startAutorotation()
-        self.done = True
 
   def handleMessage(self, message, type, args):
     if message == 'modeChanged':
@@ -97,8 +91,6 @@ class device_n900(deviceModule):
       if rotationMode:
         self.setRotationMode(rotationMode)
         print "rotation mode changed"
-    elif message == 'updateAppMenu':
-      self._updateAppMenu()
     elif message == 'updateKeys':
       self._updateVolumeKeys()
       
@@ -112,12 +104,12 @@ class device_n900(deviceModule):
   def startAutorotation(self):
     """start the GUI autorotation feature"""
     try:
-      from n900_maemo5_portrait import FremantleRotation
+      import n900_maemo5_portrait
       rotationMode = self.get('rotationMode', "auto") # get last used mode
       lastModeNumber = self.getRotationModeNumber(rotationMode) # get last used mode number
-      rotationObject = FremantleRotation(self.ossoAppName, main_window=self.modrana.topWindow, mode=lastModeNumber)
-      self.rotationObject = rotationObject
+      rObject = n900_maemo5_portrait.FremantleRotation(self.ossoAppName, main_window=self.modrana.topWindow, mode=lastModeNumber)
       print "N900 rotation object initialized"
+      return rObject
     except Exception, e:
       print e
       print "intializing N900 rotation object failed"
@@ -274,6 +266,13 @@ class device_n900(deviceModule):
     # Add the menu to the window
     self.modrana.topWindow.set_app_menu(menu)
 
+    # register callbacks to update upp menu toggle buttons
+    # when the controlled value changes from elsewhere
+    self.watch('rotateMap', self._updateAppMenu)
+    self.watch('soundEnabled', self._updateAppMenu)
+    self.watch('centred', self._updateAppMenu)
+
+
   def _toggle(self,toggleButton, key):
     print "N900: key %s toggled" % key
     self.set(key, toggleButton.get_active())
@@ -283,7 +282,8 @@ class device_n900(deviceModule):
     self.set('menu', menu)
     self.set('needRedraw', True)
 
-  def _updateAppMenu(self):
+  def _updateAppMenu(self, key=None, value=None, oldValue=None):
+    print self.get("centred",True)
     if self.centeringToggleButton:
       self.centeringToggleButton.set_active(self.get("centred",True))
     if self.rotationToggleButton:
@@ -291,6 +291,10 @@ class device_n900(deviceModule):
     if self.soundToggleButton:
       self.soundToggleButton.set_active(self.get("soundEnabled",True))
 
+  def hasKineticScrollingList(self):
+    return True
+
+
 if(__name__ == "__main__"):
   a = n900({}, {})
   a.update()
